@@ -1,4 +1,4 @@
-from fastGAT import exe
+from fastGAT/fastGAT import exe
 
 procedure=exe(save_model=True,datasetpath='./data/cora/cora',no_cuda=False,
             fastmode=False,seed=3933,epochs=200,lr=0.005,weight_delay=5e-4,hidden=8,nb_heads=4,
