@@ -10,8 +10,8 @@ import torch.nn.functional as F
 import torch.optim as optim
 from torch.autograd import Variable
 
-from .utils import load_data, accuracy
-from .model import GAT,FastGAT
+from fastGAT/utils import load_data, accuracy
+from fastGAT/model import GAT,FastGAT
 
 
 class exe(): 
